#
# spec file for package teeworlds
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           teeworlds
Version:        0.6.4
Release:        lp151.1.21
Summary:        A retro multiplayer jump-and-swing shooter
License:        Zlib and CC-BY-SA-3.0
Group:          Amusements/Games/Action/Arcade
Url:            http://www.teeworlds.com
Source:         https://downloads.teeworlds.com/%{name}-%{version}-src.tar.gz
# PATCH-FIX-OPENSUSE Allows building with optflags and system libraries.
Patch0:         teeworlds-0.6.4-extlibs-optflags.patch
# PATCH-FIX-OPENSUSE teeworlds-0.6.0-datadir.patch -- Set the game asset dir to /usr/share not relative to the binary.
Patch1:         %{name}-0.6.0-datadir.patch
# PATCH-FIX-UPSTREAM build with latest bam 0.5
Patch3:         bam-0.5.patch
# PATCH-FEATURE-UPSTREAM https://github.com/teeworlds/teeworlds/pull/1469
Patch5:         desktop.patch
BuildRequires:  ImageMagick
BuildRequires:  bam >= 0.5.0
BuildRequires:  dejavu-fonts
BuildRequires:  dos2unix
BuildRequires:  fdupes
BuildRequires:  fontpackages-devel
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  pnglite-devel
BuildRequires:  python
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(glu)
BuildRequires:  pkgconfig(sdl)
BuildRequires:  pkgconfig(wavpack)
BuildRequires:  pkgconfig(zlib)
Requires:       dejavu-fonts
Provides:       teewars = %{version}
Obsoletes:      teewars < 0.4.0
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Teeworlds is an online multiplayer game. Battles can be played with
up to 16 players in a variety of game modes, including Team
Deathmatch and Capture The Flag. Own maps can be designed.

%prep
%setup -q -n %{name}-%{version}-src
%patch0 -p1
%patch1
%patch3 -p1
%patch5 -p1

# we use system libs instead
rm -rf src/engine/external

# Fix line-endings
dos2unix license.txt readme.txt

%build
CFLAGS="%{optflags} -std=c++98 -fPIC" bam -v release

%install
mkdir -p %{buildroot}%{_datadir}
cp -a data %{buildroot}%{_datadir}/%{name}
install -D -m 0755 %{name} %{buildroot}%{_bindir}/%{name}
install -D -m 0755 %{name}_srv %{buildroot}%{_bindir}/%{name}_srv

install -D -m 0644 other/teeworlds.desktop %{buildroot}%{_datadir}/applications/%{name}.desktop
index=0
for res in 256 128 48 32 24 16; do
	mkdir -p "%{buildroot}%{_datadir}/icons/hicolor/$res"x"$res/apps"
    convert -strip "other/icons/Teeworlds.ico[$index]" "%{buildroot}%{_datadir}/icons/hicolor/$res"x"$res/apps/%{name}.png"
    index=$((index+1))
done
%suse_update_desktop_file %{name}
install -D -m 0644 other/teeworlds.appdata.xml %{buildroot}%{_datadir}/appdata/teeworlds.appdata.xml

# Unbundle DejaVu font
rm -rf %{buildroot}%{_datadir}/%{name}/fonts/*
ln -s %{_ttfontsdir}/DejaVuSans.ttf %{buildroot}%{_datadir}/%{name}/fonts/DejaVuSans.ttf

%fdupes %{buildroot}%{_datadir}

%post
%icon_theme_cache_post

%postun
%icon_theme_cache_postun

%files
%defattr(-,root,root)
%doc license.txt readme.txt
%{_bindir}/%{name}*
%{_datadir}/%{name}/
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/apps/%{name}.png
%dir %{_datadir}/appdata/
%{_datadir}/appdata/teeworlds.appdata.xml

%changelog
* Mon Apr 16 2018 antoine.belvire@opensuse.org
- Allow build with bam >= 0.5.0.
* Tue May  2 2017 bwiedemann@suse.com
- Use convert -strip to not have timestamps in png files
  to make build more reproducible
* Sat Nov 19 2016 mailaender@opensuse.org
- Update to version 0.6.4
  * Fix attacker controlled memory-writes and possibly arbitrary code execution security vulnerability in the client.
  * Fix a read of uninitialized memory that is sent over the network, from the server.
  * Fix decoding of overlong UTF-8 sequences to non-invalid code points, leading to possible duplicate names.
  * Drop connected packets that come from a formerly connected server in the client.
  * Use a different port for connless messages, increasing the difficulty of successful IP spoofing.
  * Make spoofing of server info packets harder.
  * Fix spoofing for vital chunks, and require most chunks to be vital.
  * Sort by player count by default, instead of server name.
  * Add a cooldown on unpause.
- Drop patches applied upstream
  * fix-server-vulnerability.patch
  * round.patch
- Unbundle DejaVu font
* Sat Nov  5 2016 rpm@fthiessen.de
- Fixed line endings of readme and license
* Sat Nov  5 2016 jengelh@inai.de
- Update descriptions
* Sat Jul 30 2016 mailaender@opensuse.org
- unbundle bam
- build with system libraries
- submitted the .desktop file upstream
- add an appdata.xml file (submitted for upstream inclusion)
- add round.patch to fix the build with C++ 6
* Fri Jul 29 2016 rpm@fthiessen.de
- Added fix-server-vulnerability.patch
- Replaced teeworlds.png with bundled icon.
* Sat Jan 24 2015 Mathias.Homann@opensuse.org
- Update to 0.6.3
  * Fix CVE-2014-9351 in all 0.6.x servers.
  * Fix server crash in the console code.
  * Fix master server lookup for servers.
  * Fix scripts/make_release.py script.
  * Fix client crash when opening a map with an invalid version.
* Sat May  4 2013 mailaender@opensuse.org
- Update to 0.6.2
- Switch to https://en.opensuse.org/SourceUrls
* Sun Jan 20 2013 mailaender@opensuse.org
- add license for assets
- SPDX license tags
* Sun Jan 20 2013 joop.boonen@opensuse.org
- zlib-devel and freefonts2-devel are not an auto BuildRequiment
  any more in openSUSE > 12.1
- Cleaned the spec file up
* Sun Aug  7 2011 PVince81@opensuse.org
- Updated to 0.6.1
* Sat Apr 16 2011 PVince81@opensuse.org
- Updated to 0.6.0
* Thu Mar  4 2010 adam@mizerski.pl
- Fixed no-return-in-nonvoid-function src/tools/crapnet.cpp:203
- Tagged paches
* Thu Mar  4 2010 adam@mizerski.pl
- Updated to 0.5.2
  * Fixed server flood crash
  * A bunch of smaller fixes
  * Fixed a couple of compiler warnings
* Mon Oct 12 2009 prusnak@suse.cz
- moved data to /usr/share and binaries to /usr/bin
* Thu Jan 29 2009 prusnak@suse.cz
- updated to 0.5.1
  * Hook sound fixed
  * Prediction and game timer fixed so the game should be a lot smoother now
  * Server filter that filters out non-standard maps
  * General improvements of the server browser
  * VSync fixed
  * Increased voting time from 10 seconds to 25
  * Scoreboard now works with 16 players
  * Fixed so you can't by-pass the server password
  * Tab completion and command help in the console
  * More various small fixes
* Thu Jan 15 2009 cmorve69@yahoo.es
- updated to 0.5.0
  * General
  - Demo recording and playback
  - Support for up to 16 players
  - Network and bandwidth reduction fixes
  - Some changes to better acommodate unofficial mods. Note: Mods are still
    unsupported.
  - Improved server browser: extended server info, better filtering, support
    for favorite servers
  - Server browser now has an option to filter out modded or tweaked servers,
    showing only "pure" servers. This option is enabled by default.
  - Ban support
  - Voting is now fully implemented. Admins decide what server setting can be
    voted on.
  - Support for death and non-hookable tiles
  - Move from glfw+portaudio to SDL
  - Game balance fixes
  * Maps and tilesets
  - Map pack has been updated, including six new maps (3x DM, 3x CTF)
  - Tilesets have been updated, jungle tileset added. Check your maps!
  - Non-hookable tiles (represented by new graphics)
  - Death tiles
* Mon Sep  1 2008 prusnak@suse.cz
- updated to 0.4.3
  * Auto team balance
  * Anti-spam fixes
  * Fixed editor crash on windows when saving
  * Added clear collision to the editor
  * Fixed issue with cursor being hidden on some maps
  * New version notifier
  * Silent mode for windows
  * F10 for screenshots now works in the editor
* Sun Apr 27 2008 prusnak@suse.cz
- add desktop and icon file
* Tue Apr 22 2008 prusnak@suse.cz
- build with %%optflags
* Tue Apr  8 2008 prusnak@suse.cz
- updated to 0.4.2
  * Loads of graphical optimizations. Maps now must have
    a background to behave correctly. Enable gfx_clear to get around
    faulty maps ("gfx_clear 1" in the console).
  * Fixed the welcome screen overlapping
  * sv_powerups now work again
  * Weapon switch have priority over fire now
  * Added sv_rounds_per_map to control the rounds played on each map
  * Fixed servere memory leak on linux server builds
  * Fixed issue with ping on LAN servers
  * Fixed problems with dm6 and low detail and made shotgun more visible
  * Improved the quicksearch so it's case insenitive, searches players
    aswell and highlights hits
  * Fixed server crash if you try to run ctf on a non ctf map
  * Fixed so you can't set mouse sens to 0 in the gui
  * Fixed "sample bleeding" on the blue flag
  * Fixed so say_team when you are a spectator only sends to other spectators.
  * Fixed problem with maps with 1 thick tile borders
  * Fixed so the loading text doesn't disappear if you move the mouse.
  * Added option to set the time MOTD is displayed (cl_motd_time)
  * MOTD disappears if you press escape
  * Fixed so you can do more advanced binds using "
  * Fixed so you can clear string variables by using ""
  * Fixed skidsmoke errors
  * Fixed so grenades always do 6dmg on direct hit
  * Fixed protection on the font textures so they don't get resampled
  * Added # comments to the console system
  * Added anti-spam function (sv_spamprotection)
  * Fixed so that new line correctly realigns to screen
* Wed Mar 26 2008 prusnak@suse.cz
- fixed strict aliasing (aliasing.patch)
* Wed Mar 26 2008 prusnak@suse.cz
- updated to 0.4.1
  * Added "Reset Filter" button
  * Added support for autoexec.cfg
  * Added support for spectator slots
  * Improved the MOTD
  * Made the double jump indicator more suddle
  * Fixed the shooting through walls bug
  * Fixed the detail levels of dm6
  * Fixed issue with contrasts when using custom colors
  * Fixed so maps downloads to $USER/maps
  * Fixed weapon switching bugs
  * Fixed the password entry when joining servers
  * Fixed problems with binds. Please press the "Reset to defaults" when upgrading
  * Fixed problem when player becomes spectator and holding the flag
  * Various other small fixes
* Wed Mar 26 2008 prusnak@suse.cz
- NAME CHANGE: from teewars to teeworlds (upstream change)
- updated to 0.4.0
  * Reduced latency
  * New console
  * New font system
  * New map editor
  * Graphical updates
  * Automatic downloading of maps
  * Added security
  * New binds system
  * Loads of other updates!
* Fri Feb 15 2008 prusnak@suse.cz
- copied from home:civ75
- updated to 0.3.4
- include bam building tool (svn-r117)
- put binaries in /usr/games, change datafiles paths to absolute,
  allowing them to reside in /usr/share/games/teewars (datadir.patch)
